<?php
/**
 * Create a page with the names of registered users.
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Tom N Harris <tnharris@whoopdedo.org>
 */
// must be run within Dokuwiki
if(!defined('DOKU_INC')) die();

if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'action.php');
require_once(DOKU_INC.'inc/pageutils.php');

/**
 * All DokuWiki plugins to extend the actions
 * need to inherit from this class
 */
class action_plugin_userpage extends DokuWiki_Action_Plugin {

    var $first_act = '';

    /**
     * return some info
     */
    function getInfo(){
      return array(
        'author' => 'Tom N Harris',
        'email'  => 'tnharris@whoopdedo.org',
        'date'   => 'Fri, 15 Jun 2007',
        'name'   => 'UserPage Plugin',
        'desc'   => 'Create a page with the names of registered users.',
        'url'    => 'http://whoopdedo.org/doku/wiki',
      );
    }

    function register(&$controller) {
      $controller->register_hook('ACTION_ACT_PREPROCESS','BEFORE', $this, 'preprocess_event', NULL);
      $controller->register_hook('ACTION_ACT_PREPROCESS','AFTER', $this, 'postprocess_event', NULL);
    }

    /**
     * handle user request
     */
    function preprocess_event(&$event, $param) {
      $this->first_act = $event->data;
    }
    function postprocess_event(&$event, $param) {
      global $conf;
      if ($this->first_act == 'register' && $event->data == 'login') {
        $id = $this->getConf('id');
        $ns = getNS($id);
        if(!$ns) $ns = $id;
        $user_id = $this->getConf('userid');
        if (empty($user_id)) {
          $user_id = $ns.':'.$_POST['login'];
          $user_ns = $ns;
        } else {
          $user_id = str_replace('@USER@',$_POST['login'],$user_id);
          $user_ns = getNS($user_id);
        }
        $user_id = cleanID($user_id);
        if ($this->getConf('userns')){
          $user_ns = $user_id;
          $user_id = $user_ns.':'.$conf['start'];
        }
        $tpl_found = false;
        if (!@file_exists(wikiFN($user_id)) && $this->getConf('createpage')) {
          $user_tpl = dirname(wikiFN($user_id)).'/_template.txt';
          $tpl_found = @file_exists($user_tpl);
          if (!$tpl_found){
            $user_tpl = dirname(wikiFN($id)).'/_userpage.txt';
            $tpl_found = @file_exists($user_tpl);
            if (!$tpl_found){
              $user_tpl = dirname(wikiFN($id)).'/_template.txt';
              $tpl_found = @file_exists($user_tpl);
            }
          }
          if ($tpl_found) {
            $user_tpl = io_readFile($user_tpl);
            $user_tpl = str_replace('@ID@',$user_id,$user_tpl);
            $user_tpl = str_replace('@NS@',$user_ns,$user_tpl);
            $user_tpl = str_replace('@PAGE@',noNS($user_id),$user_tpl);
            $user_tpl = str_replace('@USER@',$_POST['login'],$user_tpl);
            $user_tpl = str_replace('@NAME@',$_POST['fullname'],$user_tpl);
            $user_tpl = str_replace('@MAIL@',$_POST['email'],$user_tpl);
            $user_tpl = str_replace('@DATE@',date($conf['dformat']),$user_tpl);
            saveWikiText($user_id, $user_tpl, 'UserPage Plugin', true);
          }
        }
        $tpl = $this->getConf('template');
        $tr = array('\\n'=>"\n", '\\t'=>"\t", '\\\''=>"'", '\\\\'=>"\\");
        $tpl = strtr($tpl, $tr);
        $text = rawWiki($id);
        $tpl = str_replace('@ID@',$user_id,$tpl);
        $tpl = str_replace('@USER@',$_POST['login'],$tpl);
        $tpl = str_replace('@NAME@',$_POST['fullname'],$tpl);
        $tpl = str_replace('@EMAIL@',$_POST['email'],$tpl);
        $text .= $tpl;
        saveWikiText($id, $text, 'UserPage Plugin', true);
      }
    }

}
